"""
GuardClaw MCP module.

Provides framework-agnostic tool interception with
cryptographic audit logging.

Usage:
    from guardclaw.mcp import GuardClawMCPProxy
"""

from guardclaw.mcp.proxy import GuardClawMCPProxy

__all__ = ["GuardClawMCPProxy"]
